@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2015 Micah Lee <micah@micahflee.com>
+Copyright (C) 2016 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,17 +18,18 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import os, sys, subprocess, time, argparse, inspect, shutil, socket, threading
-import strings, helpers, web, hs
+import os, sys, time, argparse, shutil, socket, threading
+
+from . import strings, helpers, web, onion
 
 class OnionShare(object):
     """
     OnionShare is the main application class. Pass in options and run
-    start_hidden_service and it will do the magic.
+    start_onion_service and it will do the magic.
     """
     def __init__(self, debug=False, local_only=False, stay_open=False, transparent_torification=False):
         self.port = None
-        self.hs = None
+        self.onion = None
         self.hidserv_dir = None
         self.onion_host = None
 
@@ -50,17 +51,22 @@ class OnionShare(object):
 
     def choose_port(self):
         """
-        Pick an un-used port to bind to.
+        Pick an un-used port in the range 17600-17650 to bind to.
         """
         # let the OS choose a port
         tmpsock = socket.socket()
-        tmpsock.bind(("127.0.0.1", 0))
+        for port in range(17600, 17650):
+            try:
+                tmpsock.bind(("127.0.0.1", port))
+                break
+            except OSError:
+                pass
         self.port = tmpsock.getsockname()[1]
         tmpsock.close()
 
-    def start_hidden_service(self, gui=False):
+    def start_onion_service(self):
         """
-        Start the onionshare hidden service.
+        Start the onionshare onion service.
         """
         if not self.port:
             self.choose_port()
@@ -69,10 +75,10 @@ class OnionShare(object):
             self.onion_host = '127.0.0.1:{0:d}'.format(self.port)
             return
 
-        if not self.hs:
-            self.hs = hs.HS(self.transparent_torification)
+        if not self.onion:
+            self.onion = onion.Onion(self.transparent_torification)
 
-        self.onion_host = self.hs.start(self.port)
+        self.onion_host = self.onion.start(self.port)
 
     def cleanup(self):
         """
@@ -86,9 +92,9 @@ class OnionShare(object):
                 shutil.rmtree(filename)
         self.cleanup_filenames = []
 
-        # call hs's cleanup
-        if self.hs:
-            self.hs.cleanup()
+        # cleanup the onion
+        if self.onion:
+            self.onion.cleanup()
 
 
 def main(cwd=None):
@@ -96,7 +102,8 @@ def main(cwd=None):
     The main() function implements all of the logic that the command-line version of
     onionshare uses.
     """
-    strings.load_strings()
+    strings.load_strings(helpers)
+    print(strings._('version_string').format(helpers.get_version()))
 
     # onionshare CLI in OSX needs to change current working directory (#132)
     if helpers.get_platform() == 'Darwin':
@@ -134,40 +141,40 @@ def main(cwd=None):
     try:
         app = OnionShare(debug, local_only, stay_open, transparent_torification)
         app.choose_port()
-        app.start_hidden_service()
-    except hs.NoTor as e:
-        sys.exit(e.args[0])
-    except hs.HSDirError as e:
+        app.start_onion_service()
+    except onion.NoTor as e:
         sys.exit(e.args[0])
 
     # prepare files to share
-    print strings._("preparing_files")
+    print(strings._("preparing_files"))
     web.set_file_info(filenames)
     app.cleanup_filenames.append(web.zip_filename)
 
     # warn about sending large files over Tor
     if web.zip_filesize >= 157286400:  # 150mb
-        print ''
-        print strings._("large_filesize")
-        print ''
+        print('')
+        print(strings._("large_filesize"))
+        print('')
 
-    # start onionshare service in new thread
+    # start onionshare http service in new thread
     t = threading.Thread(target=web.start, args=(app.port, app.stay_open, app.transparent_torification))
     t.daemon = True
     t.start()
 
     try:  # Trap Ctrl-C
         # wait for hs, only if using old version of tor
-        if not app.local_only:
-            if not app.hs.supports_ephemeral:
-                ready = app.hs.wait_for_hs(app.onion_host)
-                if not ready:
-                    sys.exit()
+        if not app.local_only and not app.onion.supports_ephemeral:
+            ready = app.onion.wait_for_hs(app.onion_host)
+            if not ready:
+                sys.exit()
+        else:
+            # Wait for web.generate_slug() to finish running
+            time.sleep(0.2)
 
-        print strings._("give_this_url")
-        print 'http://{0:s}/{1:s}'.format(app.onion_host, web.slug)
-        print ''
-        print strings._("ctrlc_to_stop")
+        print(strings._("give_this_url"))
+        print('http://{0:s}/{1:s}'.format(app.onion_host, web.slug))
+        print('')
+        print(strings._("ctrlc_to_stop"))
 
         # wait for app to close
         while t.is_alive():
