@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2015 Micah Lee <micah@micahflee.com>
+Copyright (C) 2016 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,10 +17,11 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
-import Queue, mimetypes, platform, os, sys, urllib2
+import queue, mimetypes, platform, os, sys, socket, logging
+from urllib.request import urlopen
 from flask import Flask, Response, request, render_template_string, abort
-from functools import wraps
-import strings, helpers
+
+from . import strings, helpers
 
 app = Flask(__name__)
 
@@ -72,7 +73,8 @@ REQUEST_DOWNLOAD = 1
 REQUEST_PROGRESS = 2
 REQUEST_OTHER = 3
 REQUEST_CANCELED = 4
-q = Queue.Queue()
+REQUEST_RATE_LIMIT = 5
+q = queue.Queue()
 
 
 def add_request(request_type, path, data=None):
@@ -87,8 +89,13 @@ def add_request(request_type, path, data=None):
     })
 
 
-slug = helpers.random_string(16)
+slug = None
+def generate_slug():
+    global slug
+    slug = helpers.build_slug()
+
 download_count = 0
+error404_count = 0
 
 stay_open = False
 def set_stay_open(new_stay_open):
@@ -116,12 +123,19 @@ def get_transparent_torification():
     """
     return transparent_torification
 
+# Are we running in GUI mode?
+gui_mode = False
+def set_gui_mode():
+    """
+    Tell the web service that we're running in GUI mode
+    """
+    global gui_mode
+    gui_mode = True
+
 def debug_mode():
     """
     Turn on debugging mode, which will log flask errors to a debug file.
     """
-    import logging
-
     if platform.system() == 'Windows':
         temp_dir = os.environ['Temp'].replace('\\', '/')
     else:
@@ -131,40 +145,62 @@ def debug_mode():
     log_handler.setLevel(logging.WARNING)
     app.logger.addHandler(log_handler)
 
-def check_slug_candidate(slug):
-    def slug_dec(f):
-        @wraps(f)
-        def slug_wrapper(slug_candidate, *args, **kwargs):
-            if not helpers.constant_time_compare(slug.encode('ascii'),slug_candidate.encode('ascii')):
-                abort(404)
-            return f(*args, **kwargs)
-        return slug_wrapper
-    return slug_dec
+def check_slug_candidate(slug_candidate, slug_compare = None):
+    global slug
+    if not slug_compare:
+        slug_compare = slug
+    if not helpers.constant_time_compare(slug_compare.encode('ascii'), slug_candidate.encode('ascii')):
+        abort(404)
 
 
+# If "Stop sharing automatically" is checked (stay_open == False), only allow
+# one download at a time.
+download_in_progress = False
+
 @app.route("/<slug_candidate>")
-@check_slug_candidate(slug)
-def index():
+def index(slug_candidate):
     """
     Render the template for the onionshare landing page.
     """
+    check_slug_candidate(slug_candidate)
+
     add_request(REQUEST_LOAD, request.path)
+
+    # Deny new downloads if "Stop sharing automatically" is checked and there is
+    # currently a download
+    global stay_open, download_in_progress
+    deny_download = not stay_open and download_in_progress
+    if deny_download:
+        return render_template_string(open(helpers.get_resource_path('html/denied.html')).read())
+
+    # If download is allowed to continue, serve download page
     return render_template_string(
-        open(helpers.get_html_path('index.html')).read(),
+        open(helpers.get_resource_path('html/index.html')).read(),
         slug=slug,
         file_info=file_info,
-        filename=os.path.basename(zip_filename).decode("utf-8"),
+        filename=os.path.basename(zip_filename),
         filesize=zip_filesize,
-        filesize_human=helpers.human_readable_filesize(zip_filesize)
-    )
+        filesize_human=helpers.human_readable_filesize(zip_filesize))
 
+# If the client closes the OnionShare window while a download is in progress,
+# it should immediately stop serving the file. The client_cancel global is
+# used to tell the download function that the client is canceling the download.
+client_cancel = False
 
 @app.route("/<slug_candidate>/download")
-@check_slug_candidate(slug)
-def download():
+def download(slug_candidate):
     """
     Download the zip file.
     """
+    check_slug_candidate(slug_candidate)
+
+    # Deny new downloads if "Stop sharing automatically" is checked and there is
+    # currently a download
+    global stay_open, download_in_progress
+    deny_download = not stay_open and download_in_progress
+    if deny_download:
+        return render_template_string(open(helpers.get_resource_path('html/denied.html')).read())
+
     global download_count
 
     # each download has a unique id
@@ -183,14 +219,28 @@ def download():
     basename = os.path.basename(zip_filename)
 
     def generate():
+        # The user hasn't canceled the download
+        global client_cancel, gui_mode
+        client_cancel = False
+
+        # Starting a new download
+        global stay_open, download_in_progress
+        if not stay_open:
+            download_in_progress = True
+
         chunk_size = 102400  # 100kb
 
         fp = open(zip_filename, 'rb')
         done = False
         canceled = False
         while not done:
+            # The user has canceled the download, so stop serving the file
+            if client_cancel:
+                add_request(REQUEST_CANCELED, path, {'id': download_id})
+                break
+
             chunk = fp.read(chunk_size)
-            if chunk == '':
+            if chunk == b'':
                 done = True
             else:
                 try:
@@ -200,8 +250,8 @@ def download():
                     downloaded_bytes = fp.tell()
                     percent = (1.0 * downloaded_bytes / zip_filesize) * 100
 
-                    # suppress stdout platform on OSX (#203)
-                    if helpers.get_platform() != 'Darwin':
+                    # only output to stdout if running onionshare in CLI mode, or if using Linux (#203, #304)
+                    if not gui_mode or helpers.get_platform() == 'Linux':
                         sys.stdout.write(
                             "\r{0:s}, {1:.2f}%          ".format(helpers.human_readable_filesize(downloaded_bytes), percent))
                         sys.stdout.flush()
@@ -220,9 +270,13 @@ def download():
         if helpers.get_platform() != 'Darwin':
             sys.stdout.write("\n")
 
-        # download is finished, close the server
+        # Download is finished
+        if not stay_open:
+            download_in_progress = False
+
+        # Close the server, if necessary
         if not stay_open and not canceled:
-            print strings._("closing_automatically")
+            print(strings._("closing_automatically"))
             if shutdown_func is None:
                 raise RuntimeError('Not running with the Werkzeug Server')
             shutdown_func()
@@ -244,17 +298,34 @@ def page_not_found(e):
     404 error page.
     """
     add_request(REQUEST_OTHER, request.path)
-    return render_template_string(open(helpers.get_html_path('404.html')).read())
+
+    global error404_count
+    if request.path != '/favicon.ico':
+        error404_count += 1
+        if error404_count == 20:
+            add_request(REQUEST_RATE_LIMIT, request.path)
+            force_shutdown()
+            print(strings._('error_rate_limit'))
+
+    return render_template_string(open(helpers.get_resource_path('html/404.html')).read())
 
 # shutting down the server only works within the context of flask, so the easiest way to do it is over http
 shutdown_slug = helpers.random_string(16)
 
 
 @app.route("/<slug_candidate>/shutdown")
-@check_slug_candidate(shutdown_slug)
-def shutdown():
+def shutdown(slug_candidate):
     """
-    Stop the flask web server.
+    Stop the flask web server, from the context of an http request.
+    """
+    check_slug_candidate(slug_candidate, shutdown_slug)
+    force_shutdown()
+    return ""
+
+
+def force_shutdown():
+    """
+    Stop the flask web server, from the context of the flask app.
     """
     # shutdown the flask service
     func = request.environ.get('werkzeug.server.shutdown')
@@ -262,13 +333,13 @@ def shutdown():
         raise RuntimeError('Not running with the Werkzeug Server')
     func()
 
-    return ""
-
 
 def start(port, stay_open=False, transparent_torification=False):
     """
     Start the flask web server.
     """
+    generate_slug()
+
     set_stay_open(stay_open)
     set_transparent_torification(transparent_torification)
     app.run(port=port, threaded=True)
@@ -278,15 +349,19 @@ def stop(port):
     """
     Stop the flask web server by loading /shutdown.
     """
+
+    # If the user cancels the download, let the download function know to stop
+    # serving the file
+    global client_cancel
+    client_cancel = True
+
     # to stop flask, load http://127.0.0.1:<port>/<shutdown_slug>/shutdown
     try:
         if transparent_torification:
-            import socket
-
             s = socket.socket()
             s.connect(('127.0.0.1', port))
             s.sendall('GET /{0:s}/shutdown HTTP/1.1\r\n\r\n'.format(shutdown_slug))
         else:
-            urllib2.urlopen('http://127.0.0.1:{0:d}/{1:s}/shutdown'.format(port, shutdown_slug)).read()
+            urlopen('http://127.0.0.1:{0:d}/{1:s}/shutdown'.format(port, shutdown_slug)).read()
     except:
         pass
