@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2015 Micah Lee <micah@micahflee.com>
+Copyright (C) 2016 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,13 +18,11 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 import platform
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtWidgets, QtGui
 
-import common
 from onionshare import strings, helpers
 
-
-class ServerStatus(QtGui.QVBoxLayout):
+class ServerStatus(QtWidgets.QVBoxLayout):
     """
     The server status chunk of the GUI.
     """
@@ -46,26 +44,26 @@ class ServerStatus(QtGui.QVBoxLayout):
         self.file_selection = file_selection
 
         # server layout
-        self.status_image_stopped = QtGui.QImage(common.get_image_path('server_stopped.png'))
-        self.status_image_working = QtGui.QImage(common.get_image_path('server_working.png'))
-        self.status_image_started = QtGui.QImage(common.get_image_path('server_started.png'))
-        self.status_image_label = QtGui.QLabel()
+        self.status_image_stopped = QtGui.QImage(helpers.get_resource_path('images/server_stopped.png'))
+        self.status_image_working = QtGui.QImage(helpers.get_resource_path('images/server_working.png'))
+        self.status_image_started = QtGui.QImage(helpers.get_resource_path('images/server_started.png'))
+        self.status_image_label = QtWidgets.QLabel()
         self.status_image_label.setFixedWidth(30)
-        self.server_button = QtGui.QPushButton()
+        self.server_button = QtWidgets.QPushButton()
         self.server_button.clicked.connect(self.server_button_clicked)
-        server_layout = QtGui.QHBoxLayout()
+        server_layout = QtWidgets.QHBoxLayout()
         server_layout.addWidget(self.status_image_label)
         server_layout.addWidget(self.server_button)
 
         # url layout
         url_font = QtGui.QFont()
-        self.url_label = QtGui.QLabel()
+        self.url_label = QtWidgets.QLabel()
         self.url_label.setFont(url_font)
-        self.url_label.setWordWrap(True)
+        self.url_label.setWordWrap(False)
         self.url_label.setAlignment(QtCore.Qt.AlignCenter)
-        self.copy_url_button = QtGui.QPushButton(strings._('gui_copy_url', True))
+        self.copy_url_button = QtWidgets.QPushButton(strings._('gui_copy_url', True))
         self.copy_url_button.clicked.connect(self.copy_url)
-        url_layout = QtGui.QHBoxLayout()
+        url_layout = QtWidgets.QHBoxLayout()
         url_layout.addWidget(self.url_label)
         url_layout.addWidget(self.copy_url_button)
 
@@ -89,7 +87,7 @@ class ServerStatus(QtGui.QVBoxLayout):
 
         # set the URL fields
         if self.status == self.STATUS_STARTED:
-            self.url_label.setText('http://{0:s}/ {1:s}'.format(self.app.onion_host, self.web.slug))
+            self.url_label.setText('http://{0:s}/{1:s}'.format(self.app.onion_host, self.web.slug))
             self.url_label.show()
             self.copy_url_button.show()
 
@@ -161,21 +159,7 @@ class ServerStatus(QtGui.QVBoxLayout):
         """
         url = 'http://{0:s}/{1:s}'.format(self.app.onion_host, self.web.slug)
 
-        if platform.system() == 'Windows':
-            # Qt's QClipboard isn't working in Windows
-            # https://github.com/micahflee/onionshare/issues/46
-            import ctypes
-            GMEM_DDESHARE = 0x2000
-            ctypes.windll.user32.OpenClipboard(None)
-            ctypes.windll.user32.EmptyClipboard()
-            hcd = ctypes.windll.kernel32.GlobalAlloc(GMEM_DDESHARE, len(bytes(url)) + 1)
-            pch_data = ctypes.windll.kernel32.GlobalLock(hcd)
-            ctypes.cdll.msvcrt.strcpy(ctypes.c_char_p(pch_data), bytes(url))
-            ctypes.windll.kernel32.GlobalUnlock(hcd)
-            ctypes.windll.user32.SetClipboardData(1, hcd)
-            ctypes.windll.user32.CloseClipboard()
-        else:
-            clipboard = self.qtapp.clipboard()
-            clipboard.setText(url)
+        clipboard = self.qtapp.clipboard()
+        clipboard.setText(url)
 
         self.url_copied.emit()
